pub struct ResourceRefWriter<'a, 'n: 'a> { /* private fields */ }Expand description
Writer for a reference to a resource.
Created by XmpWriter::derived_from, XmpWriter::managed_from, or ResourceRefsWriter::add_ref.
Implementations
Sourceimpl<'a, 'n: 'a> ResourceRefWriter<'a, 'n>
impl<'a, 'n: 'a> ResourceRefWriter<'a, 'n>
Sourcepub fn alternate_paths<'b>(
&mut self,
paths: impl IntoIterator<Item = &'b str>,
) -> &mut Self
pub fn alternate_paths<'b>( &mut self, paths: impl IntoIterator<Item = &'b str>, ) -> &mut Self
Write the stRef:alternatePaths property.
Fallback paths to the resource.
Sourcepub fn document_id(&mut self, id: &str) -> &mut Self
pub fn document_id(&mut self, id: &str) -> &mut Self
Write the stRef:documentID property.
The XmpWriter::document_id of the referenced resource.
Sourcepub fn file_path(&mut self, path: &str) -> &mut Self
pub fn file_path(&mut self, path: &str) -> &mut Self
Write the stRef:filePath property.
The path or URL to the resource.
Sourcepub fn instance_id(&mut self, id: &str) -> &mut Self
pub fn instance_id(&mut self, id: &str) -> &mut Self
Write the stRef:instanceID property.
The XmpWriter::instance_id of the referenced resource.
Sourcepub fn last_modify_date(&mut self, date: DateTime) -> &mut Self
pub fn last_modify_date(&mut self, date: DateTime) -> &mut Self
Write the stRef:lastModifyDate property.
The last modification date of the resource. See ResourceEventWriter::when.
Sourcepub fn manager(&mut self, manager: &str) -> &mut Self
pub fn manager(&mut self, manager: &str) -> &mut Self
Write the stRef:manager property.
The name of the application that manages the resource. See XmpWriter::manager.
Sourcepub fn manager_variant(&mut self, variant: &str) -> &mut Self
pub fn manager_variant(&mut self, variant: &str) -> &mut Self
Write the stRef:managerVariant property.
The variant of the application that manages the resource. See XmpWriter::manager_variant.
Sourcepub fn manage_to(&mut self, uri: &str) -> &mut Self
pub fn manage_to(&mut self, uri: &str) -> &mut Self
Write the stRef:manageTo property.
The URI of the resource prior to being managed. See XmpWriter::manage_to.
Sourcepub fn manage_ui(&mut self, uri: &str) -> &mut Self
pub fn manage_ui(&mut self, uri: &str) -> &mut Self
Write the stRef:manageUI property.
An URI to the user interface of the application that manages the resource. See XmpWriter::manage_ui.
Sourcepub fn mask_markers(&mut self, markers: MaskMarkers) -> &mut Self
pub fn mask_markers(&mut self, markers: MaskMarkers) -> &mut Self
Write the stRef:maskMarkers property.
Whether to process markers for resources in the XmpWriter::ingredients array.
Sourcepub fn part_mapping(&mut self, mapping: &str) -> &mut Self
pub fn part_mapping(&mut self, mapping: &str) -> &mut Self
Write the stRef:partMapping property.
The name or URI of a mapping function to map fromPart to toPart.
Sourcepub fn rendition_class(&mut self, rendition: RenditionClass<'_>) -> &mut Self
pub fn rendition_class(&mut self, rendition: RenditionClass<'_>) -> &mut Self
Write the stRef:renditionClass property.
The rendition class of the referenced resource. See
XmpWriter::rendition_class.
Sourcepub fn rendition_params(&mut self, params: &str) -> &mut Self
pub fn rendition_params(&mut self, params: &str) -> &mut Self
Write the stRef:renditionParams property.
The rendition parameters of the referenced resource. See
XmpWriter::rendition_params.
Sourcepub fn to_part(&mut self, part: &str) -> &mut Self
pub fn to_part(&mut self, part: &str) -> &mut Self
Write the stRef:toPart property.
For a resource in a XmpWriter::ingredients array, the part of the root
resource that the the ingredient corresponds to.
Sourcepub fn version_id(&mut self, id: &str) -> &mut Self
pub fn version_id(&mut self, id: &str) -> &mut Self
Write the stRef:versionID property.
The referenced resource’s version ID. See XmpWriter::version_id.
Methods from Deref<Target = Struct<'a, 'n>>
Sourcepub fn element(
&mut self,
name: &'a str,
namespace: Namespace<'n>,
) -> Element<'_, 'n>
pub fn element( &mut self, name: &'a str, namespace: Namespace<'n>, ) -> Element<'_, 'n>
Start writing a property in the struct.
Sourcepub fn element_with_attrs<'b>(
&mut self,
name: &'a str,
namespace: Namespace<'n>,
attrs: impl IntoIterator<Item = (&'b str, &'b str)>,
) -> Element<'_, 'n>
pub fn element_with_attrs<'b>( &mut self, name: &'a str, namespace: Namespace<'n>, attrs: impl IntoIterator<Item = (&'b str, &'b str)>, ) -> Element<'_, 'n>
Start writing a property with attributes in the struct.